@@ -16,7 +16,8 @@ function http_post_data($url, $data_string) {
   ob_end_clean();
 
   $return_code = curl_getinfo($ch, CURLINFO_HTTP_CODE);
-  if($return_code !=200 && $return_code!=302) echo "HTTP return $return_code\n";
+  //if($return_code !=200 && $return_code!=302) 
+	echo "HTTP return $return_code\n";
   // return array($return_code, $return_content); 
   return $return_content;
  }
