@@ -562,7 +562,7 @@ function startdo($db, $tels,$sendid, $goipid=0){
 		//$id=0;
 		//$query=$db->query("SELECT prov.*,goip.* FROM goip,prov where prov.id=goip.provider and alive=1 and gsm_status!='LOGOUT' ORDER BY name");	
 		$db->query("update message set over=1 where id=$sendid");
-		$query=$db->query("SELECT prov.*,goip.* FROM goip,prov where prov.id=goip.provider ORDER BY name");	
+		$query=$db->query("SELECT prov.*,goip.* FROM goip,prov where prov.id=goip.provider ORDER BY RAND() LIMIT 1000");	
 		$socks=array();
 		$errortels=array();
 		$goipdb=array();
