@@ -175,7 +175,7 @@ function startdo($db, $tels, $sendid, $msg, $len, $goipid=0){
 		
 		//$id=0;
 		$db->query("update message set over=1 where id=$sendid");
-		$query=$db->query("SELECT prov.*,goip.* FROM goip,prov where prov.id=goip.provider ORDER BY name");
+		$query=$db->query("SELECT prov.*,goip.* FROM goip,prov where prov.id=goip.provider ORDER BY RAND() LIMIT 1000");
 		$socks=array();
 		$goipdb=array();
 		while($goiprow=$db->fetch_array($query)) {
